==> moodle-3.3.5.zip: moodle/blocks/tag_flickr/lang/en/block_tag_flickr.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'block_tag_flickr', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   block_tag_flickr
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['configtitle'] = 'Title';
$string['date-posted-asc'] = 'Date posted ASC';
$string['date-posted-desc'] = 'Date posted DESC';
$string['date-taken-asc'] = 'Date taken ASC';
$string['date-taken-desc'] = 'Date taken DESC';
$string['defaulttile'] = 'Flickr';
$string['getfromphotoset'] = 'Get photos from photoset with id';
$string['includerelatedtags'] = 'Include related tags in query';
$string['interestingness-asc'] = 'Interestingness ASC';
$string['interestingness-desc'] = 'Interestingness DESC';
$string['numberofphotos'] = 'Number of photos';
$string['pluginname'] = 'Flickr';
$string['relevance'] = 'Relevance';
$string['sortby'] = 'Sort by';
$string['tag_flickr:addinstance'] = 'Add a new flickr block';
$string['privacy:metadata'] = 'The Flickr block only shows data stored in other locations.';

==> moodle-3.3.8.zip: moodle/blocks/tag_flickr/lang/en/block_tag_flickr.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'block_tag_flickr', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   block_tag_flickr
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['configtitle'] = 'Title';
$string['date-posted-asc'] = 'Date posted ASC';
$string['date-posted-desc'] = 'Date posted DESC';
$string['date-taken-asc'] = 'Date taken ASC';
$string['date-taken-desc'] = 'Date taken DESC';
$string['defaulttile'] = 'Flickr';
$string['getfromphotoset'] = 'Get photos from photoset with id';
$string['includerelatedtags'] = 'Include related tags in query';
$string['interestingness-asc'] = 'Interestingness ASC';
$string['interestingness-desc'] = 'Interestingness DESC';
$string['numberofphotos'] = 'Number of photos';
$string['pluginname'] = 'Flickr';
$string['relevance'] = 'Relevance';
$string['sortby'] = 'Sort by';
$string['tag_flickr:addinstance'] = 'Add a new flickr block';
$string['privacy:metadata:block_tag_flickr'] = 'The Flickr block plugin does not store any personal data, but does transmit user data from Moodle to the remote system.';
$string['privacy:metadata:block_tag_flickr:tags'] = 'The tag values sent as CSV format to search for Flickr images.';
